@@ -94,6 +94,12 @@ sub core_indicator_names {
     return wantarray ? @all : \@all;
 }
 
+sub optional_indicator_names {
+    my $self=shift;
+    my @all=map { $_->{name} } grep { $_->{is_extra} } $self->get_indicators;
+    return wantarray ? @all : \@all;
+}
+
 q{Favourite record of the moment:
   Jahcoozi: Pure Breed Mongrel};
 
@@ -132,6 +138,10 @@ Get the list of all Kwalitee indicators as an HASHREF.
 
 Get a list of core indicator names (NOT the whole indicator HASHREF).
 
+=head3 optional_indicator_names
+
+Get a list of optional indicator names (NOT the whole indicator HASHREF).
+
 =head3 all_indicator_names
 
 Get a list of all indicator names (NOT the whole indicator HASHREF).
